@@ -687,7 +687,7 @@ xsltGetQNameURI(xmlNodePtr node, xmlChar ** name)
     if (ns == NULL) {
 	xsltGenericError(xsltGenericErrorContext,
 		"%s:%s : no namespace bound to prefix %s\n",
-		         qname, &qname[len + 1]);
+		         qname, &qname[len + 1], qname);
 	*name = NULL;
 	xmlFree(qname);
 	return(NULL);
@@ -1392,7 +1392,8 @@ xsltSaveResultTo(xmlOutputBufferPtr buf, xmlDocPtr result,
 		xmlNodeDumpOutput(buf, result, child, 0, (indent == 1),
 			          (const char *) encoding);
 		if ((child->type == XML_DTD_NODE) ||
-		    (child->type == XML_COMMENT_NODE))
+		    ((child->type == XML_COMMENT_NODE) &&
+		     (child->next != NULL)))
 		    xmlOutputBufferWriteString(buf, "\n");
 		child = child->next;
 	    }
