@@ -374,7 +374,11 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
     if (xinclude) {
 	if (timing)
 	    startTimer();
+#if LIBXML_VERSION >= 20603
+	xmlXIncludeProcessFlags(doc, XSLT_PARSE_OPTIONS);
+#else
 	xmlXIncludeProcess(doc);
+#endif
 	if (timing) {
 	    endTimer("XInclude processing %s", filename);
 	}
@@ -410,6 +414,7 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
 	ctxt = xsltNewTransformContext(cur, doc);
 	if (ctxt == NULL)
 	    return;
+	xsltSetCtxtParseOptions(ctxt, options);
 	if (profile) {
 	    res = xsltApplyStylesheetUser(cur, doc, params, NULL,
 		                          stderr, ctxt);
@@ -419,7 +424,7 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
 	}
 	if (ctxt->state == XSLT_STATE_ERROR)
 	    errorno = 9;
-	if (ctxt->state == XSLT_STATE_STOPPED)
+	else if (ctxt->state == XSLT_STATE_STOPPED)
 	    errorno = 10;
 	xsltFreeTransformContext(ctxt);
 	if (timing) {
@@ -483,6 +488,8 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
 	}
 	if (ctxt->state == XSLT_STATE_ERROR)
 	    errorno = 9;
+	else if (ctxt->state == XSLT_STATE_STOPPED)
+	    errorno = 10;
 	xsltFreeTransformContext(ctxt);
 	if (timing)
 	    endTimer("Running stylesheet and saving result");
@@ -745,6 +752,9 @@ main(int argc, char **argv)
         xmlLoadExtDtdDefaultValue = 0;
     xmlSubstituteEntitiesDefault(1);
     xmlLineNumbersDefault(1);
+#else
+    if (novalid != 0)
+	options = XML_PARSE_NOENT | XML_PARSE_NOCDATA;
 #endif
 
     /*
